EXPORTS
	?AcknowledgeLastState@RDmDomain@@QAEXXZ @ 1 NONAME ; public: void __thiscall RDmDomain::AcknowledgeLastState(void)
	?CancelTransition@RDmDomainManager@@QAEXXZ @ 2 NONAME ; public: void __thiscall RDmDomainManager::CancelTransition(void)
	?CancelTransitionNotification@RDmDomain@@QAEXXZ @ 3 NONAME ; public: void __thiscall RDmDomain::CancelTransitionNotification(void)
	?Close@RDmDomain@@QAEXXZ @ 4 NONAME ; public: void __thiscall RDmDomain::Close(void)
	?Close@RDmDomainManager@@QAEXXZ @ 5 NONAME ; public: void __thiscall RDmDomainManager::Close(void)
	?Connect@RDmDomain@@QAEHG@Z @ 6 NONAME ; public: int __thiscall RDmDomain::Connect(unsigned short)
	?Connect@RDmDomainManager@@QAEHXZ @ 7 NONAME ; public: int __thiscall RDmDomainManager::Connect(void)
	?GetPowerState@RDmDomain@@QAE?AW4TPowerState@@XZ @ 8 NONAME ; public: enum TPowerState  __thiscall RDmDomain::GetPowerState(void)
	?WaitForInitialization@RDmDomainManager@@SAHXZ @ 9 NONAME ; public: static int __cdecl RDmDomainManager::WaitForInitialization(void)
	?RequestTransitionNotification@RDmDomain@@QAEXAAVTRequestStatus@@@Z @ 10 NONAME ; public: void __thiscall RDmDomain::RequestTransitionNotification(class TRequestStatus &)
	?RequestDomainTransition@RDmDomainManager@@QAEXGW4TPowerState@@AAVTRequestStatus@@@Z @ 11 NONAME ; public: void __thiscall RDmDomainManager::RequestDomainTransition(unsigned short,enum TPowerState,class TRequestStatus &)
	?RequestSystemTransition@RDmDomainManager@@QAEXW4TPowerState@@AAVTRequestStatus@@@Z @ 12 NONAME ; public: void __thiscall RDmDomainManager::RequestSystemTransition(enum TPowerState,class TRequestStatus &)
	?SystemShutdown@RDmDomainManager@@QAEXXZ @ 13 NONAME ; public: void __thiscall RDmDomainManager::SystemShutdown(void)
	??0CDmDomain@@QAE@EG@Z @ 14 NONAME ; public: __thiscall CDmDomain::CDmDomain(unsigned char,unsigned short)
	??0CDmDomainManager@@QAE@E@Z @ 15 NONAME ; public: __thiscall CDmDomainManager::CDmDomainManager(unsigned char)
	??1CDmDomain@@UAE@XZ @ 16 NONAME ; public: virtual __thiscall CDmDomain::~CDmDomain(void)
	??1CDmDomainManager@@UAE@XZ @ 17 NONAME ; public: virtual __thiscall CDmDomainManager::~CDmDomainManager(void)
	??1CHierarchyObserver@@UAE@XZ @ 18 NONAME ; public: virtual __thiscall CHierarchyObserver::~CHierarchyObserver(void)
	?AcknowledgeLastState@CDmDomain@@QAEXH@Z @ 19 NONAME ; public: void __thiscall CDmDomain::AcknowledgeLastState(int)
	?AcknowledgeLastState@RDmDomain@@QAEXH@Z @ 20 NONAME ; public: void __thiscall RDmDomain::AcknowledgeLastState(int)
	?AddDomainHierarchy@CDmDomainManager@@SAHE@Z @ 21 NONAME ; public: static int __cdecl CDmDomainManager::AddDomainHierarchy(unsigned char)
	?AddDomainHierarchy@RDmDomainManager@@SAHE@Z @ 22 NONAME ; public: static int __cdecl RDmDomainManager::AddDomainHierarchy(unsigned char)
	?Connect@RDmDomain@@QAEHEG@Z @ 23 NONAME ; public: int __thiscall RDmDomain::Connect(unsigned char,unsigned short)
	?Connect@RDmDomainManager@@QAEHE@Z @ 24 NONAME ; public: int __thiscall RDmDomainManager::Connect(unsigned char)
	?ConstructL@CDmDomain@@IAEXXZ @ 25 NONAME ; protected: void __thiscall CDmDomain::ConstructL(void)
	?ConstructL@CDmDomainManager@@IAEXXZ @ 26 NONAME ; protected: void __thiscall CDmDomainManager::ConstructL(void)
	?DoCancel@CDmDomain@@MAEXXZ @ 27 NONAME ; protected: virtual void __thiscall CDmDomain::DoCancel(void)
	?DoCancel@CDmDomainManager@@MAEXXZ @ 28 NONAME ; protected: virtual void __thiscall CDmDomainManager::DoCancel(void)
	?GetState@CDmDomain@@QAEIXZ @ 29 NONAME ; public: unsigned int __thiscall CDmDomain::GetState(void)
	?GetState@RDmDomain@@QAEIXZ @ 30 NONAME ; public: unsigned int __thiscall RDmDomain::GetState(void)
	?GetTransitionFailureCount@CDmDomainManager@@QAEHXZ @ 31 NONAME ; public: int __thiscall CDmDomainManager::GetTransitionFailureCount(void)
	?GetTransitionFailureCount@RDmDomainManager@@QAEHXZ @ 32 NONAME ; public: int __thiscall RDmDomainManager::GetTransitionFailureCount(void)
	?GetTransitionFailures@CDmDomainManager@@QAEHAAV?$RArray@$$CBVTTransitionFailure@@@@@Z @ 33 NONAME ; public: int __thiscall CDmDomainManager::GetTransitionFailures(class RArray<class TTransitionFailure const > &)
	?GetTransitionFailures@RDmDomainManager@@QAEHAAV?$RArray@$$CBVTTransitionFailure@@@@@Z @ 34 NONAME ; public: int __thiscall RDmDomainManager::GetTransitionFailures(class RArray<class TTransitionFailure const > &)
	?NewL@CHierarchyObserver@@SAPAV1@AAVMHierarchyObserver@@E@Z @ 35 NONAME ; public: static class CHierarchyObserver * __cdecl CHierarchyObserver::NewL(class MHierarchyObserver &,unsigned char)
	?ObserverDomainCount@CHierarchyObserver@@QAEHXZ @ 36 NONAME ; public: int __thiscall CHierarchyObserver::ObserverDomainCount(void)
	?RequestDomainTransition@CDmDomainManager@@QAEXGIW4TDmTraverseDirection@@@Z @ 37 NONAME ; public: void __thiscall CDmDomainManager::RequestDomainTransition(unsigned short,unsigned int,enum TDmTraverseDirection)
	?RequestDomainTransition@RDmDomainManager@@QAEXGIW4TDmTraverseDirection@@AAVTRequestStatus@@@Z @ 38 NONAME ; public: void __thiscall RDmDomainManager::RequestDomainTransition(unsigned short,unsigned int,enum TDmTraverseDirection,class TRequestStatus &)
	?RequestSystemTransition@CDmDomainManager@@QAEXIW4TDmTraverseDirection@@@Z @ 39 NONAME ; public: void __thiscall CDmDomainManager::RequestSystemTransition(unsigned int,enum TDmTraverseDirection)
	?RequestSystemTransition@RDmDomainManager@@QAEXIW4TDmTraverseDirection@@AAVTRequestStatus@@@Z @ 40 NONAME ; public: void __thiscall RDmDomainManager::RequestSystemTransition(unsigned int,enum TDmTraverseDirection,class TRequestStatus &)
	?RequestTransitionNotification@CDmDomain@@QAEXXZ @ 41 NONAME ; public: void __thiscall CDmDomain::RequestTransitionNotification(void)
	?StartObserver@CHierarchyObserver@@QAEHGW4TDmNotifyType@@@Z @ 42 NONAME ; public: int __thiscall CHierarchyObserver::StartObserver(unsigned short,enum TDmNotifyType)
	?StopObserver@CHierarchyObserver@@QAEHXZ @ 43 NONAME ; public: int __thiscall CHierarchyObserver::StopObserver(void)
	??0CDmDomainKeepAlive@@QAE@EG@Z @ 44  NONAME ; public: __thiscall CDmDomainKeepAlive::CDmDomainKeepAlive(unsigned char,unsigned short)
	??1CDmDomainKeepAlive@@UAE@XZ @ 45  NONAME ; public: virtual __thiscall CDmDomainKeepAlive::~CDmDomainKeepAlive(void)
	?AcknowledgeLastState@CDmDomainKeepAlive@@QAEXH@Z @ 46  NONAME ; public: void __thiscall CDmDomainKeepAlive::AcknowledgeLastState(int)
	?CancelDeferral@RDmDomain@@QAEXXZ @ 47  NONAME ; public: void __thiscall RDmDomain::CancelDeferral(void)
	?ConstructL@CDmDomainKeepAlive@@IAEXXZ @ 48  NONAME ; protected: void __thiscall CDmDomainKeepAlive::ConstructL(void)
	?DeferAcknowledgement@RDmDomain@@QAEXAAVTRequestStatus@@@Z @ 49  NONAME ; public: void __thiscall RDmDomain::DeferAcknowledgement(class TRequestStatus &)
	?RunL@CDmDomainKeepAlive@@MAEXXZ @ 50  NONAME ; protected: virtual void __thiscall CDmDomainKeepAlive::RunL(void)
	?HandleDeferralError@CDmDomainKeepAlive@@UAEHH@Z @ 51  NONAME ; public: virtual int __thiscall CDmDomainKeepAlive::HandleDeferralError(int)
	
